<?php

/**
 * The plugin controllers.
 *
 * PHP version 5
 *
 * @category  CMSimple_XH
 * @package   Fotorama
 * @author    Christoph M. Becker <cmbecker69@gmx.de>
 * @copyright 2015 Christoph M. Becker <http://3-magi.net>
 * @license   http://www.gnu.org/licenses/gpl-3.0.en.html GNU GPLv3
 */

/**
  @modifiziert  ab Version 1.7 - 2018 I.Sell <knollsen@gmx.net>
  @link         http://pluginxh.iseye.eu
*/
class Fotorama_Controller {
  /**
   * Dispatches on plugin related requests.
   *
   * @return void
   */
  public function dispatch() {
    if (defined('XH_ADM') && XH_ADM) {
        if (function_exists('XH_registerStandardPluginMenuItems')) {
            XH_registerStandardPluginMenuItems(true);
        }
        if ($this->isAdministrationRequested()) {
            $this->handleAdministration();
        }
    }
  }

  /**
   * Returns whether the plugin administration is requested.
   *
   * @return bool
   *
   * @global string Whether the plugin administration is requested.
   */
  protected function isAdministrationRequested() {
    global $fotorama;

    return function_exists('XH_wantsPluginAdministration')
        && XH_wantsPluginAdministration('fotorama')
        || isset($fotorama) && $fotorama == 'true';
  }

  /**
   * Handles the plugin administration.
   *
   * @return void
   *
   * @global string The value of the <var>admin</var> G/P parameter.
   * @global string The value of the <var>action</var> G/P parameter.
   * @global string (X)HTML fragment to be inserted into the content area.
   */
  protected function handleAdministration() {
    global $admin, $action, $o;

    $o .= print_plugin_admin('on');
    switch ($admin) {
    case '':
        $o .= $this->renderPluginInfo();
        break;
    case 'plugin_main':
        switch ($action) {
        case 'create':
            $this->createGallery();
            break;
        case 'edit':
            $o .= $this->renderGalleryEditor();
            break;
        case 'save':
            $this->saveGallery();
            break;
        case 'delete':
            $this->deleteGallery();
            break;
        case 'refresh':
            $this->refreshGallery();
            break;
        case 'delcache':
            $this->deleteCache();
            break;
        case 'delallcache':
            $this->deleteAllCache();
            break;
        default:
            $o .= $this->renderGalleryList();
        }
        break;
    default:
        $o .= plugin_admin_common($action, $admin, 'fotorama');
    }
  }

  /**
   * Renders the plugin info.
   *
   * @return string (X)HTML
   *
   * @global array The paths of system files and folders.
   * @global array The localization of the plugins.
   */
  protected function renderPluginInfo() {
    global $pth, $plugin_tx;

    return '<h1>Fotorama</h1>'
        . tag(
            'img src="' . $pth['folder']['plugins'] . 'fotorama/fotorama.png"'
            . ' class="fotorama_logo" alt="'
            . $plugin_tx['fotorama']['alt_logo'] . '"'
        )
        . '<p>Version: '.FOTORAMA_VERSION.'</p>'
        . '<p>Codeeditor_XH is powered by <a href="http://fotorama.io/">'
        . 'Fotorama</a>.</p>'
        . '<p>Copyright &copy; 2015 <a href="http://3-magi.net">'
        . 'Christoph M. Becker</a></p>'
        . '<p class="fotorama_license">This program is free software:'
        . 'you can redistribute it and/or modify'
        . ' it under the terms of the GNU General Public License as published by'
        . ' the Free Software Foundation, either version 3 of the License, or'
        . ' (at your option) any later version.</p>'
        . '<p class="fotorama_license">This program is distributed in the hope'
        . ' that it will be useful,'
        . ' but <em>without any warranty</em>; without even the implied warranty'
        . ' of <em>merchantability</em> or <em>fitness for a particular purpose'
        . '</em>.  See the GNU General Public License for more details.</p>'
        . '<p class="fotorama_license">You should have received a copy of the'
        . ' GNU General Public License'
        . ' along with this program.  If not, see'
        . ' <a href="http://www.gnu.org/licenses/">http://www.gnu.org/licenses/'
        . '</a>.</p>'
        . '<p class="fotorama_license">Dieses Plugin wurde weiterentwickelt von <a href="https://iseye.eu/">ISEYE</a> - 2018 (Ingo Sell)<br>Download: <a href="http://pluginxh.iseye.eu/?Plugins/wdir" target="_blank">Download FOTORAMA</a><br>Testseite: <a href="http://pluginxh.iseye.eu/?Plugins/Fotorama" target="_blank">Test von FOTORAMA-Plugin</a></p>';
  }

  /**
   * Renders the gallery list.
   *
   * @return string
   *
   * @global string            The script name.
   * @global array             The localization of the plugins.
   * @global XH_CSRFProtection The CSRF protector.
   */
  protected function renderGalleryList() {
    global $sn, $plugin_tx, $_XH_csrfProtection;

    $url = $sn . '?&fotorama&admin=plugin_main&action=edit&fotorama_gallery=';
    $html = '<h1>Fotorama &ndash; ' . $plugin_tx['fotorama']['menu_main']
        . '</h1>'
        . '<ul>';
    $files = new DirectoryIterator($this->findContentFolder());
    foreach ($files as $file) {
        $filename = $file->getFilename();
        if (pathinfo($filename, PATHINFO_EXTENSION) == 'xml') {
            $basename = basename($filename, '.xml');
            $html .= '<li><a href="' . XH_hsc($url . $basename) . '">'
                . $basename . '</a></li>';
        }
    }
    $html .= '</ul>'
        . '<div id="fotorama_admin"><form action="' . $sn . '?&amp;fotorama" method="post">'
        . $_XH_csrfProtection->tokenInput()
        . tag('input type="hidden" name="admin" value="plugin_main"')
        . '<fieldset><legend><strong>'.$plugin_tx['fotorama']['label_create_gallery'].'</strong></legend>'
        . '<p><label>'.$plugin_tx['fotorama']['label_name'].' '
        . tag('input type="text" name="fotorama_gallery"')
        . '</label></p>'
        . '<p><label>'.$plugin_tx['fotorama']['label_folder'].' '
        . $this->renderImageFolderSelect()
        . '</label></p>'
        . '<p><button class="submit" name="action" value="create">'
        . $plugin_tx['fotorama']['label_create'].'</button>'
        . '<button class="submit" name="action" value="delallcache">'
        . $plugin_tx['fotorama']['label_clear_whole_cache'].'</button></p>'
        . '</fieldset>'
        . '</form></div>';
    return $html;
  }

  /**
   * Renders an image folder select element.
   *
   * @return string (X)HTML
   *
   * @global array The paths of system files and folders.
   */
  protected function renderImageFolderSelect() {
    global $pth;

    return '<select name="fotorama_folder">'
        . $this->renderImageFolderSelectOptions($pth['folder']['userfiles'], '')
        . '</select>';
  }

  /**
   * Renders the select options of an image folder.
   *
   * @param string $path   A folder path.
   * @param string $prefix A prefix.
   *
   * @return string (X)HTML
   */
  protected function renderImageFolderSelectOptions($path, $prefix) {
    $html = '';
    $files = new DirectoryIterator($path);
    foreach ($files as $file) {
      if (!$file->isDot() && $file->isDir()) {
        $html .= '<option>' . $prefix . $file->getFilename() . '</option>';
        $html .= $this->renderImageFolderSelectOptions(
            $file->getPathname(), $prefix . $file->getFilename() . '/'
        );
      }
    }
    return $html;
  }

  /**
   * Renders a gallery editor.
   *
   * @return string
   *
   * @global string The script name.
   * @global array  The localization of the plugins.
   * @global XH_CSRFProtection The CSRF protector.
   */
  protected function renderGalleryEditor($xml=false) {
    global $sn, $plugin_tx, $_XH_csrfProtection, $pth;

    if (isset($_GET['fotorama_gallery'])) {
        $name = $this->sanitizeName($_GET['fotorama_gallery']);
    } else {
        $name = $this->sanitizeName($_POST['fotorama_gallery']);
    }
    $deleteImage = $pth['folder']['plugins'].'fotorama/images/delete.png';
    $contents = ($xml) ? $xml : file_get_contents($this->findContentFolder() . $name . '.xml');
    $contents = $this->xmlEscape($contents);
    $gal = simplexml_load_string($contents);
    $galattr = $gal->attributes();
    $pics = $gal->xpath('pic');

$fo = '<h1>Fotorama &ndash; "' . $name . '"</h1>
<div id="fotorama_admin">
<form name="myform" action="'.$sn.'?&amp;fotorama" method="post">
<table>
<thead>
  <tr>
    <th>'.$plugin_tx['fotorama']['setting_width'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_ratio'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_fit'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_nav'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_navposition'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_thumbfit'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_fullscreen'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_transition'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_autoplay'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_loop'].'</th>
    <th>'.$plugin_tx['fotorama']['setting_folder'].'</th>
  </tr>
</thead>
<tbody>
    <tr>
      <td>
        <input type="text" name="fotorama_width" value="'.$galattr->width.'"/>
      </td>
      <td>
        <input type="text" name="fotorama_ratio" value="'.$galattr->ratio.'"/>
      </td>
      <td>
        <select name="fotorama_fit">
          <option value="contain" '.(($galattr->fit == 'contain')?'selected="selected"':'').'>contain</option>
          <option value="cover" '.(($galattr->fit == 'cover')?'selected="selected"':'').'>cover</option>
          <option value="scaledown" '.(($galattr->fit == 'scaledown')?'selected="selected"':'').'>scaledown</option>
          <option value="none" '.(($galattr->fit == 'none')?'selected="selected"':'').'>none</option>
        </select>
      </td>
      <td>
        <select name="fotorama_nav">
          <option value="dots" '.(($galattr->nav == 'dots')?'selected="selected"':'').'>dots</option>
          <option value="thumbs" '.(($galattr->nav == 'thumbs')?'selected="selected"':'').'>thumbs</option>
          <option value="false" '.(($galattr->nav == 'false')?'selected="selected"':'').'>false</option>
        </select>
      </td>
      <td>
        <select name="fotorama_navposition">
          <option value="top" '.(($galattr->navposition == 'top')?'selected="selected"':'').'>top</option>
          <option value="bottom" '.(($galattr->navposition == 'bottom')?'selected="selected"':'').'>bottom</option>
        </select>
      </td>
      <td>
        <select name="fotorama_thumbfit">
          <option value="contain" '.(($galattr->thumbfit == 'contain')?'selected="selected"':'').'>contain</option>
          <option value="cover" '.(($galattr->thumbfit == 'cover')?'selected="selected"':'').'>cover</option>
          <option value="scaledown" '.(($galattr->thumbfit == 'scaledown')?'selected="selected"':'').'>scaledown</option>
          <option value="none" '.(($galattr->thumbfit == 'none')?'selected="selected"':'').'>none</option>
        </select>
      </td>
      <td>
        <select name="fotorama_fullscreen">
          <option value="false" '.(($galattr->fullscreen == 'false')?'selected="selected"':'').'>false</option>
          <option value="true" '.(($galattr->fullscreen == 'true')?'selected="selected"':'').'>true</option>
          <option value="native" '.(($galattr->fullscreen == 'native')?'selected="selected"':'').'>native</option>
        </select>
      </td>
      <td>
        <select name="fotorama_transition">
          <option value="slide" '.(($galattr->transition == 'slide')?'selected="selected"':'').'>slide</option>
          <option value="crossfade" '.(($galattr->transition == 'crossfade')?'selected="selected"':'').'>crossfade</option>
          <option value="dissolve" '.(($galattr->transition == 'dissolve')?'selected="selected"':'').'>dissolve</option>
        </select>
      </td>
      <td style="text-align:center;">
        <input type="hidden" name="fotorama_autoplay" value="false"/>
        <input type="checkbox" name="fotorama_autoplay" value="true" '.(($galattr->autoplay == 'true')?'checked="checked"':'').'/>
      </td>
      <td style="text-align:center;">
        <input type="hidden" name="fotorama_loop" value="false"/>
        <input type="checkbox" name="fotorama_loop" value="true" '.(($galattr->loop == 'true')?'checked="checked"':'').'/>
      </td>
      <td>
        <input type="text" name="fotorama_path" value="'.$galattr->path.'"/>
      </td>
    </tr>
    </tbody>
  </table>
  <p> </p>
  <table id="picTable">
  <thead>
  <tr>
    <th>'.$plugin_tx['fotorama']['table_title'].'</th>
    <th>'.$plugin_tx['fotorama']['table_video'].'</th>
    <th>'.$plugin_tx['fotorama']['table_thumb'].'</th>
    <th width="30">'.$plugin_tx['fotorama']['table_del'].'</th>
  </tr>
</thead>
<tbody>';
  foreach ($pics as $i => $pic) {
    $picattr = $pic->attributes();
    $fo .= '
    <tr>
    <td>
      <input type="text" name="fotorama_caption[]" value="'.$picattr->caption.'"/>
    </td>
    <td>
      <input type="text" name="fotorama_video[]" value="'.$picattr->video.'"/>
    </td>
    <td>
      <input type="text" name="fotorama_pic[]" value="'.$picattr->path.'" onmouseover="ShowImage(\'./userfiles/'.$galattr->path.'/'.$picattr->path.'\',this)" onmouseout="HideImage()"/>
    </td>
    <td style="text-align: center">
      <input type="image" src="'.$deleteImage.'" alt='.$plugin_tx['fotorama']['label_delete'].' title='.$plugin_tx['fotorama']['label_delete'].' value="Delete" onclick="delRow(this)"/>
    </td>
    </tr>';
  }
  $fo .= '
</tbody>
</table>
<input type="hidden" name="admin" value="plugin_main"/>
<input type="hidden" name="fotorama_gallery" value="'.$name.'"/>
<input type="hidden" name="delnode" value=""/>
<button name="action" value="save">'.$plugin_tx['fotorama']['label_save'].'</button>
<button name="action" value="delete">'.$plugin_tx['fotorama']['label_delete'].'</button>
<button name="action" value="refresh">'.$plugin_tx['fotorama']['label_actualise'].'</button>
<button name="action" value="delcache">'.$plugin_tx['fotorama']['label_clear_cache'].'</button>
</form>
<div id="fotorama_popup" style="display: none;">
   <img id="fotorama_img"/> 
</div>
<button style="position: absolute;right:0;" onclick="createRow()">'.$plugin_tx['fotorama']['label_create_field'].'</button>
<button onclick="upNdown(\'up\')">&ShortUpArrow;</button>
<button onclick="upNdown(\'down\')">&ShortDownArrow;</button>
<script>
  var index;
  function getSelectedRow() {
    var table = document.getElementById("picTable");
    for(var i = 1; i < table.rows.length; i++) {
      table.rows[i].onclick = function() {
        if(typeof index !== "undefined"){
          table.rows[index].classList.toggle("selected");
        }
        index = this.rowIndex;
        this.classList.toggle("selected");
      }
    }
  }
  getSelectedRow();

  function upNdown(direction) {
    if (index) {
      var rows = document.getElementById("picTable").rows, parent = rows[index].parentNode;
      if(direction === "up") {
        if(index > 1) {
          parent.insertBefore(rows[index],rows[index - 1]);
          index--;
        }
      }
      if(direction === "down") {
        if(index < rows.length -1) {
          parent.insertBefore(rows[index + 1],rows[index]);
          index++;
        }
      }
    }
  }

  function delRow(r) {
    var i = r.parentNode.parentNode.rowIndex;
    document.getElementById("picTable").deleteRow(i);
  }
  function createRow() {
    var table = document.getElementById("picTable");
    var row = table.insertRow();
    var cell0 = row.insertCell(0);
    var cell1 = row.insertCell(1);
    var cell2 = row.insertCell(2);
    var cell3 = row.insertCell(3);
    cell0.innerHTML = "<input type=\"text\" name=\"fotorama_caption[]\" value=\"\"/>";
    cell1.innerHTML = "<input type=\"text\" name=\"fotorama_video[]\" value=\"\"/>";
    cell2.innerHTML = "<input type=\"text\" name=\"fotorama_pic[]\" value=\"\"/>";
    cell3.innerHTML = "<input  type=\"image\" src=\"'.$deleteImage.'\" alt=\"delete\" title=\"delete\"  value=\"Delete\" onclick=\"delRow(this)\"/>";
  }

  function ShowImage(src,obj) {
    var x, y, right, bottom;
    var xoffset = 15;
    var yoffset = 10;
    var pop = document.getElementById("fotorama_popup");
    var img = document.getElementById("fotorama_img");
    var ext = src.lastIndexOf(".");
    if(!ext) return "";
    img.src = src;
    pop.style.display = "block";

    right = (document.documentElement.clientWidth || document.body.clientWidth || document.body.scrollWidth);
    bottom = (window.scrollY || document.documentElement.scrollTop || document.body.scrollTop) + (window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight || document.body.scrollHeight);

    obj.onmousemove = function(e) {
      x = e.clientX;
      y = e.clientY;
      
      if (x > right-pop.offsetWidth-xoffset) x = x-pop.offsetWidth-xoffset;
      else x += xoffset;
      if (y > bottom-pop.offsetHeight-yoffset) y = y-pop.offsetHeight-yoffset;
      else y += yoffset;

      pop.style.left = x+"px";
      pop.style.top = y+"px";
    }
  }
  function HideImage() {
    document.getElementById("fotorama_popup").style.display = "none";
  }
</script>
</div>';
      return $fo;
    }

  /**
   * Creates a gallery.
   *
   * @return void
   *
   * @global array             The paths of system files and folders.
   * @global array             The localization of the plugins.
   * @global string            (X)HTML fragment to insert into the contents area.
   * @global XH_CSRFProtection The CSRF protector.
   */
  protected function createGallery() {
    global $pth, $plugin_tx, $o, $_XH_csrfProtection;

    $_XH_csrfProtection->check();
    $messages = '';
    $name = $_POST['fotorama_gallery'];
    $path = $_POST['fotorama_folder'];
    $filename = $pth['folder']['userfiles'] . $path;
    $xml = '<?xml version="1.0" encoding="UTF-8" standalone="no"?>' . PHP_EOL
        . '<!DOCTYPE gallery SYSTEM "'.$pth['folder']['plugins'].'fotorama/help/gallery.dtd">'.PHP_EOL
        . '<gallery width="100%" ratio="16/9" fit="contain" nav="thumbs" navposition="bottom" thumbfit="contain" fullscreen="true" transition="slide" autoplay="false" loop="true" path="' . $path . '">' . PHP_EOL;
    if (is_dir($filename)) {
      $files = new DirectoryIterator($filename);
      foreach ($files as $file) {
        $filename = $file->getPathname();
        $filendung = $this->fileextension($filename);
        if (is_file($filename) && getimagesize($filename) && strtolower($filendung) != "swf") {
          $xml .= '    <pic caption="" video="" path="'.$file->getFilename().'"/>'
               . PHP_EOL;
        }else if (is_file($filename)) {
          $xml .= '    <pic caption="" video="'.$file->getFilename().'" path=""/>'
               . PHP_EOL;
        }
      }
    } else {
      $messages .= XH_message(
          'warning', $plugin_tx['fotorama']['message_no_folder'], $filename
      );
    }
    $xml .= '</gallery>' . PHP_EOL;
    if (!$this->isValidName($name)) {
      $messages .= XH_message(
          'fail', $plugin_tx['fotorama']['message_invalid_name'], $name
      );
    } else {
      $filename = $pth['folder']['content'] . 'fotorama/' . $name . '.xml';
      if (file_exists($filename)) {
          $messages .= XH_message(
              'fail', $plugin_tx['fotorama']['message_exists'], $filename
          );
      } elseif (!file_put_contents($filename, $xml)) {
          $messages .= XH_message(
              'fail', $plugin_tx['fotorama']['message_cant_save'], $filename
          );
      }
    }
    if (!$messages) {
      $this->relocate(
          '?&fotorama&admin=plugin_main&action=edit&fotorama_gallery=' . $name
      );
    } else {
      $o .= $messages . $this->renderGalleryList();
    }
  }

  /**
   * Saves a gallery.
   *
   * @return string
   *
   * @global array  The paths of system files and folders.
   * @global array  The configuration of the plugins.
   * @global array  The localization of the plugins.
   * @global XH_CSRFProtection The CSRF protector.
   * @global string (X)HTML fragment to insert into the contents area.
   */
  protected function saveGallery() {
    global $pth, $plugin_cf, $plugin_tx, $_XH_csrfProtection, $o;

    //$_XH_csrfProtection->check();
    $messages = '';
    $name = $this->sanitizeName($_POST['fotorama_gallery']);
    $captions = $_POST['fotorama_caption'];
    $videos = $_POST['fotorama_video'];
    $pics = $_POST['fotorama_pic'];
    $xml = '<?xml version="1.0" encoding="UTF-8" standalone="no"?>' . PHP_EOL
        . '<!DOCTYPE gallery SYSTEM "'.$pth['folder']['plugins'].'fotorama/help/gallery.dtd">'.PHP_EOL
        . '<gallery width="'.$_POST['fotorama_width'].'" ratio="'.$_POST['fotorama_ratio'].'" fit="'.$_POST['fotorama_fit'].'" nav="'.$_POST['fotorama_nav'].'" navposition="'.$_POST['fotorama_navposition'].'" thumbfit="'.$_POST['fotorama_thumbfit'].'" fullscreen="'.$_POST['fotorama_fullscreen'].'" transition="'.$_POST['fotorama_transition'].'" autoplay="'.$_POST['fotorama_autoplay'].'" loop="'.$_POST['fotorama_loop'].'" path="'.$_POST['fotorama_path'].'">' . PHP_EOL;
    foreach ($pics as $i => $pi) {
      $videos[$i] = $this->xmlEscape($videos[$i]);
      $xml .= '<pic caption="'.$captions[$i].'" video="'.$videos[$i].'" path="'.$pi.'"/>'
           . PHP_EOL;
    }
    $xml .= '</gallery>' . PHP_EOL;
    $xml;
    if ($plugin_cf['fotorama']['xml_auto_validate'] && !$this->validate($xml)) {
        $messages .= XH_message(
            'warning', $plugin_tx['fotorama']['message_invalid_xml']
        );
    }
    $filename = $pth['folder']['content'] . 'fotorama/' . $name . '.xml';
    if (!file_put_contents($filename, $xml)) {
        $messages .= XH_message(
            'fail', $plugin_tx['fotorama']['message_cant_save'], $filename
        );
    }
    if (!$messages) {
        $this->relocate('?&fotorama&admin=plugin_main&action=plugin_text');
    } else {
        $o .= $messages . $this->renderGalleryEditor();
    }
  }

	protected function deleteGallery() {
    global $pth;
		$messages = '';
		$name = $this->sanitizeName($_POST['fotorama_gallery']);
		$filename = $pth['folder']['content'] . 'fotorama/' . $name . '.xml';
		if (file_exists($filename)) {
			$this->deleteCache(true);
			unlink($filename);
		}
		$this->relocate('?&fotorama&admin=plugin_main&action=plugin_text');
	}

	protected function refreshGallery() {
    global $pth, $o;
		if (isset($_GET['fotorama_gallery'])) {
      $name = $this->sanitizeName($_GET['fotorama_gallery']);
    } else {
      $name = $this->sanitizeName($_POST['fotorama_gallery']);
    }
		$path = $this->findContentFolder() . $name . '.xml';
		$gallery = simplexml_load_file($path);
    $filename = $pth['folder']['userfiles'] . $gallery['path'];
//print_r($gallery);
//echo "<br><br>".$filename." | ".$path." <br> ";
//echo $gallery['autoplay']." | ";
		$xml = '<?xml version="1.0" encoding="UTF-8" standalone="no"?>' . PHP_EOL
        . '<!DOCTYPE gallery SYSTEM "'.$pth['folder']['plugins'].'fotorama/help/gallery.dtd">'.PHP_EOL
        . '<gallery width="'.$gallery['width'].'" ratio="'.$gallery['ratio'].'" fit="'.$gallery['fit'].'" nav="'.$gallery['nav'].'" navposition="'.$gallery['navposition'].'" thumbfit="'.$gallery['thumbfit'].'" fullscreen="'.$gallery['fullscreen'].'" transition="'.$gallery['transition'].'" autoplay="'.$gallery['autoplay'].'" loop="'.$gallery['loop'].'" path="'.$gallery['path'].'">' . PHP_EOL;

		if (is_dir($filename)) {
      $files = new DirectoryIterator($filename);
      foreach ($files as $file) {
        $filename = $file->getPathname();
        $filendung = $this->fileextension($filename);
        if (is_file($filename) && getimagesize($filename) && strtolower($filendung) != "swf") {
          $dirfile[] = (string)$file->getFilename();
//echo $file->getFilename().' | ';
          $caption = '';
          foreach ($gallery->pic as $pic) {
            if ((string)$pic['path'] ==  $file->getFilename()) {
//echo (string)$pic['caption'].' # ';
              $caption = (string)$pic['caption'];
            }
          }
          $xml .= '<pic caption="'.$caption.'" video="" path="'.$file->getFilename().'"/>'
               . PHP_EOL;
        }else if (is_file($filename)) {
          $dirfile[] = (string)$file->getFilename();
//echo $file->getFilename().' | ';
          $caption = '';
          foreach ($gallery->pic as $pic) {
            if ((string)$pic['video'] ==  $file->getFilename()) {
//echo (string)$pic['caption'].' # ';
              $caption = (string)$pic['caption'];
            }
          }
          $xml .= '<pic caption="'.$caption.'" video="'.$file->getFilename().'" path=""/>'
               . PHP_EOL;
        }
      }
    }
		$xml .= '</gallery>' . PHP_EOL;
//echo htmlentities($xml);
		$o .= $this->renderGalleryEditor($xml);
	}

	protected function deleteCache($delgal=false) {
    global $pth;
		if (isset($_GET['fotorama_gallery'])) {
        $name = $this->sanitizeName($_GET['fotorama_gallery']);
    } else {
        $name = $this->sanitizeName($_POST['fotorama_gallery']);
    }
		$path = $this->findContentFolder() . $name . '.xml';
    $gallery = simplexml_load_file($path);
		foreach ($gallery->pic as $pic) {
      $caption = XH_hsc(isset($pic['caption']) ? $pic['caption'] : '');
      $filepath = $pth['folder']['userfiles'] . $gallery['path'] . '/' . $pic['path'];
			$md5 = md5($filepath);
			$thumb = $pth['folder']['plugins'] . 'fotorama/cache/'."{$md5}_64.".$this->fileextension($filepath);
			if (file_exists($thumb)) {
				unlink($thumb);
			}
    }
		if(!$delgal) $this->relocate('?&fotorama&admin=plugin_main&action=plugin_text');
	}

	protected function deleteAllCache() {
    global $pth;
		$dir = $pth['folder']['plugins'].'fotorama/cache/';
		foreach(glob($dir.'*.*') as $v){
			unlink($v);
		}
		$this->relocate('?&fotorama&admin=plugin_main&action=plugin_text');
	}

  /**
   * Validates the given XML.
   *
   * @param string $xml An XML string.
   *
   * @return bool
   */
  protected function validate($xml) {
      $doc = new DomDocument();
      return $doc->loadXML($xml) && $doc->validate();
  }

  /**
   * Returns whether a given name is a valid gallery name.
   *
   * @param string $name A gallery name.
   *
   * @return bool
   */
  protected function isValidName($name) {
      return preg_match('/^[a-z0-9-]+$/', $name);
  }

  /**
   * Returns the sanitized gallery name.
   *
   * @param string $name A gallery name.
   *
   * @return string
   */
  protected function sanitizeName($name) {
      return preg_replace('/[^a-z0-9-]/', '', $name);
  }

  /**
   * Sends a relocation header.
   *
   * @param string $url An URL to relocate to.
   *
   * @return void
   */
  protected function relocate($url) {
      header('Location: ' . CMSIMPLE_URL . $url);
      exit();
  }

  /**
   * Returns the path of the content folder. If the folder does not exist, it
   * is created.
   *
   * @return string
   *
   * @global array The paths of system files and folders.
   */
  protected function findContentFolder() {
      global $pth;

      $folder = $pth['folder']['content'] . 'fotorama/';
      if (!file_exists($folder)) {
          mkdir($folder, 0777);
          chmod($folder, 0777);
      }
      return $folder;
  }

  protected function fileextension($filename) {
    return (false === ( $p = strrpos($filename, '.')) ? '' : substr($filename, ++$p));
  }
  
  protected function xmlEscape($string) {
    return str_replace(array('&', '\''), array('&amp;', '&apos;'), $string);
  }
}

?>