<?php

/**
 * The gallery views.
 *
 * PHP version 5
 *
 * @category  CMSimple_XH
 * @package   Fotorama
 * @author    Christoph M. Becker <cmbecker69@gmx.de>
 * @copyright 2015 Christoph M. Becker <6>
 * @license   http://www.gnu.org/licenses/gpl-3.0.en.html GNU GPLv3
 */

/**
  @modifiziert  ab Version 1.7 - 2019 I.Sell <knollsen@gmx.net>
  @link         http://pluginxh.iseye.eu
*/
class Fotorama_GalleryView {
  /**
   * The gallery name.
   *
   * @var string
   */
  protected $name;

  /**
   * Initializes a new instance.
   *
   * @param string $name A gallery name.
   */
  public function __construct($name)
  {
      $this->name = $name;
  }

  /**
   * Renders the gallery.
   *
   * @return string (X)HTML
   *
   * @global array The paths of system files and folders.
   */
  public function render() {
    global $pth, $plugin_tx, $plugin_cf;

    $pcf = $plugin_cf['fotorama'];
    $ptx = $plugin_tx['fotorama'];
    $path = $pth['folder']['content'] . 'fotorama/' . $this->name . '.xml';
    if (file_exists($path)) $gallery = simplexml_load_file($path);
    else return '<p>Datei konnte nicht gefunden werden!</p>';
    //$this->emitJS();
    $html = $this->renderGalleryStartTag($gallery);
    $index = 0;
    foreach ($gallery->pic as $pic) {
      $privacy = '';
      $caption = XH_hsc(isset($pic['caption']) ? $pic['caption'] : '');
      $filename = (trim($pic['path']) != '') ? $pth['folder']['userfiles'].$gallery['path'].'/'.$pic['path'] : '';

      $src = '';
      if ($this->urlhttppath($pic['video']) || trim($pic['video']) != '') {
          $video = $this->parse_video(trim($pic['video']));
        if ($video['type'] == 'youtube') {
          if (!$filename && $pcf['video_get_picture_thumb']) $filename = $this->makePicUrl($video['thumb'], $video['type'], $gallery, $index);
          if ($pcf['video_privacy_policy_external']) $privacy = sprintf($ptx['privacy_text'], 'YouTube').'<br>YouTube (Google)';
          $provider = '<br>YouTube (Google)';
          $src = $video['scheme'].'://www.youtube-nocookie.com'.$video['path'].'?rel=0&amp;autoplay=1&amp;wmode=transparent'.$video['parameter'].'" width="560" height="315" allowfullscreen="allowfullscreen" id="myVideo"';
        }else if ($video['type'] == 'vimeo') {
          if (!$filename && $pcf['video_get_picture_thumb']) $filename = $this->makePicUrl($video['thumb'], $video['type'], $gallery, $index);
          if ($pcf['video_privacy_policy_external']) $privacy = sprintf($ptx['privacy_text'], 'vimeo').'<br>vimeo.com';
          $src = $video['scheme'].'://player.vimeo.com/video'.$video['path'].'?autoplay=1&amp;badge=0'.$video['parameter'].'" frameborder="0" allowfullscreen width="560" height="315" id="myVideo"';
        }else if ($video['type'] == 'dailymotion') {
          if (!$filename && $pcf['video_get_picture_thumb']) $filename = $this->makePicUrl($video['thumb'], $video['type'], $gallery, $index);
          if ($pcf['video_privacy_policy_external']) $privacy = sprintf($ptx['privacy_text'], 'dailymotion').'<br>dailymotion.com';
          $src = $video['scheme'].'://'.$video['host'].$video['path'].'?autoplay=1&amp;info=0&amp;logo=0&amp;social=0&amp;related=0'.$video['parameter'].'" frameborder="0" allowfullscreen width="560" height="315" id="myVideo"';
        }else if ($video['type'] == 'wistia') {
          if (!$filename && $pcf['video_get_picture_thumb']) $filename = $this->makePicUrl($video['thumb'], $video['type'], $gallery, $index);
          if ($pcf['video_privacy_policy_external']) $privacy = sprintf($ptx['privacy_text'], 'wistia').'<br>wistia.com';
          $src = $video['scheme'].'://'.$video['host'].'/embed/iframe/'.$video['id'].'?autoPlay=true'.$video['parameter'].'" allowtransparency="true" frameborder="0" scrolling="no" width="560" height="315" id="myVideo"';
        }else if ($video['type'] == 'custom') {
          $hostname = @gethostbyaddr($video['host']);
          $hostn = ($hostname) ? $hostname : $video['host'];
          if ($pcf['video_privacy_policy_external']) $privacy = sprintf($ptx['privacy_text'], $hostn).'<br>'.$hostn;
          $src = $pic['video'];
        }else if ($video['type'] == 'local' || $video['type'] == 'flash') {
          if ($pcf['video_privacy_policy_local']) $privacy = sprintf($ptx['privacy_text'], 'local').'<br>'.sv('SERVER_NAME');
          $src = $pth['folder']['userfiles'] . $gallery['path'].'/'.$pic['video'];
        }

        if (!$filename) $filename = $video['thumb'];
        $html .= '<a href="'.$src.'" data-video="true" data-img="'.$filename.'" data-caption="'.$caption.'" data-privacy="'.$privacy.'">';
      }else{
        $html .= '<a href="'.$filename.'" data-caption="'.$caption.'">';
      }

      $thumbnail = $this->makeThumbnail($filename, 64);
      $index++;

      $html .= tag(
        'img src="' . $thumbnail . '" data-caption="' . $caption
        . '" alt="' . $caption . '"'
      );
      $html .= '</a>';
    }
    $html .= '</div>';
    return $html;
  }
  
  protected function parse_video($url) {
    global $pth, $plugin_cf;
    $pcf = $plugin_cf['fotorama'];
    $parse = parse_url($url);
    $video_parameter = '';
    $video_type = '';
    $video_id = '';
    $video_thumb = '';

    if (isset($parse['host'])) {
      $host_names = explode(".", $parse['host'] );
      $rebuild = (!empty($host_names[1]) ? $host_names[1] : '').'.'.(!empty($host_names[2]) ? $host_names[2] : '');

      if ($parse['host'] == 'youtu.be' ) {
        $video_type = 'youtube';
        $video_id = ltrim($parse['path'],'/' );
        $quali = '/default.jpg';
        if ($pcf['video_pic_quality'] == 'small') $quali = '/mqdefault.jpg';
        else if ($pcf['video_pic_quality'] == 'medium') $quali = '/hqdefault.jpg';
        else if ($pcf['video_pic_quality'] == 'large') $quali = '/maxresdefault.jpg';
        $video_thumb = ($pcf['video_get_picture_thumb']) ? 'http://img.youtube.com/vi/'.$video_id.$quali : $pth['folder']['plugins'].'fotorama/movie.jpg';
        $parse['path'] = '/embed'.$parse['path'];
        $video_parameter = isset($parse['query']) ? '&'.$parse['query'] : '';
      }else if (($parse['host'] == 'youtube.com') || ($parse['host'] == 'www.youtube.com') || ($parse['host'] == 'youtube-nocookie.com') || ($parse['host'] == 'www.youtube-nocookie.com')) {
        $video_type = 'youtube';
        if (strpos($parse['path'], 'embed') == 1) $video_id = @end((explode('/', $parse['path'])));
        if ($pcf['video_pic_quality'] == 'small') $quali = '/mqdefault.jpg';
        else if ($pcf['video_pic_quality'] == 'medium') $quali = '/hqdefault.jpg';
        else if ($pcf['video_pic_quality'] == 'large') $quali = '/maxresdefault.jpg';
        $video_thumb = ($pcf['video_get_picture_thumb']) ? 'http://img.youtube.com/vi/'.$video_id.$quali : $pth['folder']['plugins'].'fotorama/movie.jpg';
        $video_parameter = isset($parse['query']) ? '&'.$parse['query'] : '';
      }else if (($parse['host'] == 'vimeo.com') || ($parse['host'] == 'www.vimeo.com')) {
        $video_type = 'vimeo';
        $video_id = ltrim($parse['path'],'/');
        $video_thumb = ($pcf['video_get_picture_thumb']) ? $this->get_vimeo_thumbnail($video_id,$pcf) : $pth['folder']['plugins'].'fotorama/movie.jpg';
        $video_parameter = isset($parse['fragment']) ? '#'.$parse['fragment'] : '';
      }else if (($parse['host'] == 'dailymotion.com') || ($parse['host'] == 'www.dailymotion.com')) {
        $video_type = 'dailymotion';
        if (strpos($parse['path'], 'embed') == 1) {
          $video_id = @end((explode('/', $parse['path'])));
          $video_thumb = ($pcf['video_get_picture_thumb']) ? $this->get_dailymotion_thumbnail($video_id,$pcf) : $pth['folder']['plugins'].'fotorama/movie.jpg';
          $video_parameter = isset($parse['query']) ? '&'.$parse['query'] : '';
        }
      }else if (($rebuild == 'wistia.com') || ($rebuild == 'wi.st.com')) {
        $video_type = 'wistia';
        if (strpos($parse['path'], 'embed') == 1) {
          $video_id = @end((explode('/', $parse['path'])));
          $video_thumb = ($pcf['video_get_picture_thumb']) ? $this->get_wistia_thumbnail($url) : $pth['folder']['plugins'].'fotorama/movie.jpg';
          $video_parameter = isset($parse['query']) ? '&'.$parse['query'] : '';
        }else{
          $video_thumb = $pth['folder']['plugins'].'fotorama/movie.jpg';
        }
      }else{
        $video_type = 'custom';
        $video_thumb = $pth['folder']['plugins'].'fotorama/custom.jpg';
      }
    }else{
      $video_id = @end((explode('/', $parse['path'])));
      $filendung = $this->fileextension($video_id);
      if (strtolower($filendung) == "swf") {
        $video_type = 'flash';
        $video_thumb = $pth['folder']['plugins'].'fotorama/flash.jpg';
      }else{
        $video_type = 'local';
        $video_thumb = $pth['folder']['plugins'].'fotorama/movie.jpg';
      }
    }
    // If recognised type return video array
    if (!empty($video_type)) {
      $video_array = array(
        'scheme' => isset($parse['scheme']) ? $parse['scheme'] : '',
        'host' => isset($parse['host']) ? $parse['host'] : '',
        'path' => $parse['path'],
        'parameter' => $video_parameter,
        'type' => $video_type,
        'thumb' => $video_thumb,
        'id' => $video_id
      );
      return $video_array;
    } else {
      return false;
    }
  }

  protected function get_vimeo_thumbnail($v_id, $pcf) {
    $vimeo_api = 'http://vimeo.com/api/v2/video/' . $v_id . '.php';
    $vimeo = unserialize(file_get_contents($vimeo_api));
    $quali = '';
    if ($pcf['video_pic_quality'] == 'small') $quali = $vimeo[0]['thumbnail_small'];
    else if ($pcf['video_pic_quality'] == 'medium') $quali = $vimeo[0]['thumbnail_medium'];
    else if ($pcf['video_pic_quality'] == 'large') $quali = $vimeo[0]['thumbnail_large'];
    return $quali;
  }

  protected function get_dailymotion_thumbnail($v_id, $pcf) {
    $quali = '';
    if ($pcf['video_pic_quality'] == 'small') $quali = 'thumbnail_small_url';
    else if ($pcf['video_pic_quality'] == 'medium') $quali = 'thumbnail_medium_url';
    else if ($pcf['video_pic_quality'] == 'large') $quali = 'thumbnail_large_url';
    $dailymotion_api = 'https://api.dailymotion.com/video/'.$v_id.'?fields='.$quali.'';
    $dailymotion_response = @json_decode(file_get_contents($dailymotion_api), true);
    return $dailymotion_response[$quali];
  }

  protected function get_wistia_thumbnail($video) {
    if (empty($video)) return false;
    $wistia_api = 'http://fast.wistia.com/oembed?url=' . $video;
    $wistia_response = @json_decode(file_get_contents($wistia_api), true);
    return $wistia_response['thumbnail_url'];
  }

  /**
   * Renders the start tag of a gallery.
   *
   * @param SimpleXMLElement $gallery A gallery.
   *
   * @return string (X)HTML
   */
  protected function renderGalleryStartTag($gallery) {
    $html = '<div class="fotorama"';
    if (isset($gallery['width'])) {
        $html .= ' data-width="' . $gallery['width'] . '"';
    }
    if (isset($gallery['ratio'])) {
        $html .= ' data-ratio="' . $gallery['ratio'] . '"';
    }
    if (isset($gallery['fit'])) {
        $html .= ' data-fit="' . $gallery['fit'] . '"';
    }
    if (isset($gallery['nav'])) {
        $html .= ' data-nav="' . $gallery['nav'] . '"';
    }
    if (isset($gallery['navposition'])) {
        $html .= ' data-navposition="' . $gallery['navposition'] . '"';
    }
    if (isset($gallery['fullscreen'])) {
        $html .= ' data-allowfullscreen="' . $gallery['fullscreen'] . '"';
    }
    if (isset($gallery['transition'])) {
        $html .= ' data-transition="' . $gallery['transition'] . '"';
    }
    if (isset($gallery['thumbfit'])) {
        $html .= ' data-thumbfit="' . $gallery['thumbfit'] . '"';
    }
    if (isset($gallery['autoplay'])) {
        $html .= ' data-autoplay="' . $gallery['autoplay'] . '"';
    }
    if (isset($gallery['loop'])) {
        $html .= ' data-loop="' . $gallery['loop'] . '"';
    }
    $html .= '>';
    return $html;
  }

  /**
   * Emits the required JavaScript.
   *
   * @return void
   *
   * @global array  The paths of system files and folders.
   * @global string (X)HTML fragment to be inserted into the <head> element.
   */
  protected function emitJS() {
    global $hjs, $pth;

    include_once $pth['folder']['plugins'] . 'jquery/jquery.inc.php';
    include_jquery();
    $hjs .= tag('link rel="stylesheet" type="text/css" href="'.$pth['folder']['plugins'].'fotorama/lib/fotorama.css"'
    );
    include_jqueryplugin(
        'fotorama', $pth['folder']['plugins'] . 'fotorama/lib/fotorama.js'
    );
  }

  protected function makePicUrl($path, $name, $gallery, $index) {
    global $pth, $plugin_cf;

    $img_content = @file_get_contents($path);
    if ($this->urlhttppath($path) && $img_content) {
      $bname = uniqid().'_'.$name.'.jpg';
      $gallery->pic[$index]['path'] = $bname;
      $gallery->asXml($pth['folder']['content'].'fotorama/'.$this->name.'.xml');
      $filename = $pth['folder']['userfiles'].$gallery['path'].'/'.$bname;
      if(file_put_contents($filename, $img_content)) {
        if(file_exists($filename))
          return $filename;
      }
    }
    return $pth['folder']['plugins'].'fotorama/movie.jpg';
  }

  /**
   * Creates a cached thumbnail if necessary, and returns its path.
   *
   * @param string $path A file path.
   * @param int    $size A minimum size in pixels.
   *
   * @return string
   *
   * @global array The paths of system files and folders.
   */
  protected function makeThumbnail($path, $size) {
    global $pth, $plugin_cf;

    $foo = ($plugin_cf['fotorama']['image_scale_size_width']) ? TRUE : FALSE;

    $Bilddaten = @getimagesize($path);
    if($Bilddaten[2]==1) {
      $fileendung = "gif";
    }else if($Bilddaten[2]==2) {
      $fileendung = "jpg";
    }else if($Bilddaten[2]==3) {
      $fileendung = "png";
    }else{
      return;
    }

    $localpathtime = false;
    $md5 = md5($path);
    $thumb = $pth['folder']['plugins'] . 'fotorama/cache/'."{$md5}_{$size}.".$fileendung;
    if (!$this->urlhttppath($path)) {
      $localpathtime = (file_exists($thumb) && filemtime($thumb) < filemtime($path)) ? true : false;
    }

    if (!file_exists($thumb) || $localpathtime) {
      $orgdest = '';
      if($Bilddaten[2]==1) {
        $source = imagecreatefromgif($path);
      }else if($Bilddaten[2]==2) {
        $source = imagecreatefromjpeg($path);
      }else if($Bilddaten[2]==3) {
        $source = imagecreatefrompng($path);
      }
      $w1 = imagesx($source);
      $h1 = imagesy($source);

      if ($foo && ($plugin_cf['fotorama']['image_scale_size_width'] < $w1)) {
        if ($w1 < $h1) {
          $orgh = $plugin_cf['fotorama']['image_scale_size_width'];
          $orgw = $orgh / $h1 * $w1;
        } else {
          $orgw = $plugin_cf['fotorama']['image_scale_size_width'];
          $orgh = $orgw / $w1 * $h1;
        }
        $orgdest = imagecreatetruecolor($orgw, $orgh);
        imagecopyresampled($orgdest, $source, 0, 0, 0, 0, $orgw, $orgh, $w1, $h1);
        if($Bilddaten[2]==1) {
          imagegif($orgdest, $path);
        }else if($Bilddaten[2]==2) {
          imagejpeg($orgdest, $path);
        }else if($Bilddaten[2]==3) {
          imagepng($orgdest, $path);
        }
        imagedestroy($orgdest);
      }

      if ($w1 < $h1) {
        $w2 = $size;
        $h2 = $w2 / $w1 * $h1;
      } else {
        $h2 = $size;
        $w2 = $h2 / $h1 * $w1;
      }

      $dest = imagecreatetruecolor($w2, $h2);
      imagecopyresampled($dest, $source, 0, 0, 0, 0, $w2, $h2, $w1, $h1);
      if($Bilddaten[2]==1) {
        imagegif($dest, $thumb);
      }else if($Bilddaten[2]==2) {
        imagejpeg($dest, $thumb);
      }else if($Bilddaten[2]==3) {
        imagepng($dest, $thumb);
      }
      imagedestroy($source);
      imagedestroy($dest);
    }    
    return $thumb;
  }

  protected function fileextension($filename) {
    return (false === ( $p = strrpos($filename, '.')) ? '' : substr($filename, ++$p));
  }

  protected function urlhttppath($path) {
    return (strpos($path, "http://") !== false || strpos($path, "https://") !== false) ? true : false;
  }
}

?>